import{N as l}from"./NavbarControls.3c018bbc.js";import{d as _,ey as f,ez as y,F as g,a as v,b as c,et as h,f as e,w as s,u as r,e as k,bo as w,ao as S,c as x,eS as T,t as q}from"./outputWidgets.149ec695.js";import{A as C}from"./Text.726003d1.js";import{T as I,A as a}from"./TabPane.6d7facbb.js";import{c as A}from"./index.3b52e48e.js";import"./asyncComputed.89365f8b.js";import"./index.efbcd225.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.238d1a0c.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.6fa5c9ed.js";import"./ant-design.4d2ef4d2.js";import"./index.1570e79d.js";import"./Modal.cf793feb.js";import"./storage.d8354481.js";import"./Link.264bf752.js";import"./index.82c2fc86.js";import"./Title.d69f1878.js";import"./index.29be2bff.js";import"./workspaces.7af81da6.js";import"./record.5c1f9715.js";import"./pubsub.f0cce5f6.js";import"./url.9af78d6c.js";import"./popupNotifcation.4f2814fb.js";import"./CircularLoading.dc6ee5e5.js";import"./icons.ce69a27b.js";import"./index.bd5511e9.js";import"./hasIn.708aa645.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="b584e432-58d3-4bb4-9879-2cb63e45f869",o._sentryDebugIdIdentifier="sentry-dbid-b584e432-58d3-4bb4-9879-2cb63e45f869")}catch{}})();const B={class:"content"},D=_({__name:"Settings",setup(o){const t=f(),n=y();function m(){t.push({name:"home"})}const p=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function u(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(r(A),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(l,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(r(C),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(r(I),{"active-key":p.value,onChange:u},{default:s(()=>[e(r(a),{key:"style",tab:"Style"}),e(r(a),{key:"sidebar",tab:"Sidebar"}),e(r(a),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",B,[e(d,null,{default:s(({Component:b})=>[(c(),x(T(b)))]),_:1})])],64)}}});const ae=q(D,[["__scopeId","data-v-772f4b10"]]);export{ae as default};
//# sourceMappingURL=Settings.1e0daee6.js.map
