import{S as p}from"./Sidebar.31def67e.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.b0d5184e.js";import{G as d,H as l,I as u}from"./icons.ce69a27b.js";import{d as b,ez as f,F as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.149ec695.js";import{a as z}from"./asyncComputed.89365f8b.js";import"./router.35f50650.js";import"./jwt-decode.esm.74bd4619.js";import"./index.737a9c1b.js";import{O as w}from"./organization.3d0a6ba4.js";import{B as I}from"./BaseLayout.3f668266.js";import"./index.2ed092ca.js";import"./logo.084e5d7c.js";import"./Text.726003d1.js";import"./index.3b52e48e.js";import"./FormItem.338256bd.js";import"./hasIn.708aa645.js";import"./storage.d8354481.js";import"./index.fc8ecc48.js";import"./index.cf4c23b9.js";import"./record.5c1f9715.js";import"./pubsub.f0cce5f6.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="2f4c86ae-0358-4709-a1fe-872e5841cba9",o._sentryDebugIdIdentifier="sentry-dbid-2f4c86ae-0358-4709-a1fe-872e5841cba9")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:a}=z(()=>w.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.597155d3.js.map
