import{d as c,ez as m,u as e,b as d,c as u,et as y,f as a,w as o,be as _,ao as p,ev as g,e as b,eB as x}from"./outputWidgets.149ec695.js";import"./router.35f50650.js";import"./jwt-decode.esm.74bd4619.js";import"./index.737a9c1b.js";import{O as w}from"./organization.3d0a6ba4.js";import{a as h}from"./asyncComputed.89365f8b.js";import{a as k}from"./Title.d69f1878.js";import{A as B}from"./index.bd5511e9.js";import{A}from"./index.1ba4f37c.js";import{A as C}from"./Text.726003d1.js";import{C as I}from"./Card.a0b0846d.js";import"./FormItem.338256bd.js";import"./hasIn.708aa645.js";import"./storage.d8354481.js";import"./index.fc8ecc48.js";import"./index.cf4c23b9.js";import"./record.5c1f9715.js";import"./pubsub.f0cce5f6.js";import"./TabPane.6d7facbb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="2bdddce9-40da-4f7a-b9fa-c50d0b31a46d",t._sentryDebugIdIdentifier="sentry-dbid-2bdddce9-40da-4f7a-b9fa-c50d0b31a46d")}catch{}})();const v={key:1},z={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},X=c({__name:"Billing",setup(t){const n=m().params.organizationId,{loading:l,result:f}=h(()=>w.get(n));return(D,T)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",v,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(k),{level:3},{default:o(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(A),{style:{"margin-top":"0"}}),a(e(I),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),b("div",z,x((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{X as default};
//# sourceMappingURL=Billing.a3f6128d.js.map
