import{cu as n}from"./outputWidgets.149ec695.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="0494b16b-8216-4e6e-a8b3-f79f26f3b498",e._sentryDebugIdIdentifier="sentry-dbid-0494b16b-8216-4e6e-a8b3-f79f26f3b498")}catch{}})();const t=(e,r)=>{n.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.4f2814fb.js.map
