import{t as n,b as d,et as s}from"./outputWidgets.149ec695.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3d3d1470-b9f9-4f8e-b026-c175d0ad5db0",e._sentryDebugIdIdentifier="sentry-dbid-3d3d1470-b9f9-4f8e-b026-c175d0ad5db0")}catch{}})();const o={},r={class:"organization-settings"};function i(e,t){return d(),s("div",r,"Organization settings")}const f=n(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.486dc6ff.js.map
