var o=Object.defineProperty;var i=(t,a,e)=>a in t?o(t,a,{enumerable:!0,configurable:!0,writable:!0,value:e}):t[a]=e;var n=(t,a,e)=>(i(t,typeof a!="symbol"?a+"":a,e),e);import{g as c,h as d,_ as f}from"./outputWidgets.149ec695.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="aaa62b9d-a583-485a-9fd3-2640f0bc2590",t._sentryDebugIdIdentifier="sentry-dbid-aaa62b9d-a583-485a-9fd3-2640f0bc2590")}catch{}})();const u=[{path:"/:path(.*)*",name:"player",component:()=>f(()=>import("./Player.6558b0a8.js"),["assets/Player.6558b0a8.js","assets/FormRunner.16e53c84.js","assets/outputWidgets.149ec695.js","assets/outputWidgets.bd537527.css","assets/url.9af78d6c.js","assets/storage.d8354481.js","assets/pubsub.f0cce5f6.js","assets/jwt-decode.esm.74bd4619.js","assets/icons.ce69a27b.js","assets/CircularLoading.dc6ee5e5.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.ab75a2e0.js","assets/PlayerNavbar.ead94b03.css","assets/ActionButton.e75d1766.js","assets/ActionButton.f74e60ec.css","assets/WidgetsFrame.fc53de63.js","assets/WidgetsFrame.97ae601d.css","assets/index.ff1ab8b2.js","assets/Card.a0b0846d.js","assets/TabPane.6d7facbb.js","assets/hasIn.708aa645.js","assets/index.82c2fc86.js","assets/Text.726003d1.js","assets/Link.264bf752.js","assets/Title.d69f1878.js","assets/FormRunner.8ff3f1ac.css","assets/uuid.89e9d67f.js","assets/asyncComputed.89365f8b.js","assets/Player.6fed9080.css"])}],g=c({history:d("/"),routes:u,scrollBehavior(t){if(t.hash)return{el:t.hash}}});async function w(){const t=await fetch("/_settings");if(!t.ok)throw new Error(await t.text());const a=await t.json();await r.init(a)}const s=class{constructor(a){this.config=a}static async init(a){s.instance=new s(a)}get showWatermark(){return this.config.show_watermark}get isStagingRelease(){return{}.VITE_ABSTRA_RELEASE==="staging"}get isLocal(){return location.origin.match(/http:\/\/localhost:\d+/)}};let r=s;n(r,"instance",null);export{r as S,g as a,u as r,w as s};
//# sourceMappingURL=index.efbcd225.js.map
