import{Q as s}from"./outputWidgets.149ec695.js";import{c as i,d as a}from"./index.b9951a14.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="89cddfd2-b18e-4330-bd54-f75f90096c3f",e._sentryDebugIdIdentifier="sentry-dbid-89cddfd2-b18e-4330-bd54-f75f90096c3f")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:d}=i(a),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:d,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,d as R,r as W};
//# sourceMappingURL=dayjs.5eb20998.js.map
