import"./outputWidgets.149ec695.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3e2b0501-35bd-412a-a708-e10c18a9c6fd",e._sentryDebugIdIdentifier="sentry-dbid-3e2b0501-35bd-412a-a708-e10c18a9c6fd")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.9af78d6c.js.map
