import{Q as n,f as c,N as i,e7 as b,a9 as u}from"./outputWidgets.149ec695.js";import{B as f,b as y}from"./Text.726003d1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="1fdbea0e-a390-479c-a82c-1e7e3c076caf",e._sentryDebugIdIdentifier="sentry-dbid-1fdbea0e-a390-479c-a82c-1e7e3c076caf")}catch{}})();const h=()=>i(y(),["component"]),s=(e,a)=>{let{slots:o,attrs:t}=a;const r=n(n(n({},e),{component:"div"}),t);return c(f,r,o)};s.displayName="ATypographyParagraph";s.inheritAttrs=!1;s.props=h();const w=s;var m=globalThis&&globalThis.__rest||function(e,a){var o={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&a.indexOf(t)<0&&(o[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)a.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(o[t[r]]=e[t[r]]);return o};const P=b(1,2,3,4,5),T=()=>n(n({},i(y(),["component","strong"])),{level:Number}),p=(e,a)=>{let{slots:o,attrs:t}=a;const{level:r=1}=e,d=m(e,["level"]);let l;P.includes(r)?l=`h${r}`:(u(),l="h1");const g=n(n(n({},d),{component:l}),t);return c(f,g,o)};p.displayName="ATypographyTitle";p.inheritAttrs=!1;p.props=T();const O=p;export{w as A,O as a};
//# sourceMappingURL=Title.d69f1878.js.map
